@@ -449,3 +449,22 @@ class AlephAPI(object):
                     raise ae
                 backoff(ae, attempt)
         return {}
+
+    def create_entityset(
+        self, collection_id: str, type: str, label: str, summary: Optional[str]
+    ) -> Dict:
+        """Create an EntitySet inside a collection"""
+        url = self._make_url("entitysets")
+        data: Dict = {
+            "collection_id": collection_id,
+            "type": type,
+            "label": label,
+            "summary": summary,
+            "entities": [],
+        }
+        return self._request("POST", url, data=data)
+
+    def delete_entityset(self, entityset_id: str, sync: bool = False):
+        """Delete an EntitySet by id"""
+        url = self._make_url(f"entitysets/{entityset_id}", sync=sync)
+        return self._request("DELETE", url)
